#!/bin/bash
# image conversion script

# env
export VIPSHOME=/usr/local/vips
export IM_CONCURRENCY=1
nip2=$VIPSHOME/bin/run-nip2.sh

# args
image_path=$1
output_name=$2

#echo "PATH: @@$image_path""@@";
#exit

# drop the suffix on the filename
dir=`dirname "$image_path"` 
file=`basename "$image_path"` 
base=${file%*.*}

# needs a .nip2-xx/ if we come from apache
# also, need one writable by us (probably www-data if from apache)
export HOME=/tmp/image_server/`whoami`

# and make sure it's there
if [[ ! -d $HOME ]]; then
	mkdir -p $HOME
fi

#output_name="$output_path$base-PYR.tif";
temp="$HOME/temp-PYR.tif";	

bd=`$VIPSHOME/bin/header -f "Bbits" "$image_path"`;
ba=`$VIPSHOME/bin/header -f "Bands" "$image_path"`;
tp=`$VIPSHOME/bin/header -f "Type" "$image_path"`;

if [ $bd -eq 16  ] && [ $ba -eq 1  ] && [ $tp -eq 1  ]; then
	output="$temp:,tile:256x256,pyramid";
else
	output="$temp:jpeg:75,tile:256x256,pyramid";		
fi

#Do we sharpen
sharp=1

#if [ -f "$output_name" ]; then
#	echo "SKIPPING: $output_name already exists."	
#else
#	echo "CREATING $output_name"


$VIPSHOME/bin/run-nip2.sh -bmdp -o "$output" <<EOF


exb b n x
	= [], to_real n == 0
	= extract_bands b n x;
		
// fit an image to a print size, or a width in pixels
stage_sRGB in 
	= in_a
{
	in_a = colour_transform_to Image_type.sRGB in;
} 

stage_RGB16 in 
	= colour_transform_to Image_type.sRGB (Image (im_icc_import in.value "/usr/local/vips/share/nip2/data/sRGB.icm" 1)), in.type == 25
	= in;

stage_BW in 
	= colour_transform_to Image_type.sRGB (scale (colour_transform_to Image_type.B_W in)), in.type == 26
	= in;
	
stage_4band in
  = map_unary (exb 0 3) in, in.bands == 4;
  = in;

stage_saturate in 
	= in, in.coding != 0
	= in_b
{
	in_a = colour_transform_to Image_type.LCH in;
	in_b = in_a * Vector [1, 1.15, 1];
} 

stage_sharp in
	= in, "$sharp" == "none"
	= in, $sharp == 0
	= if in_l?0 > 99 then Vector [100, 0, 0] else out
{
	in_l = colour_transform_to Image_type.LAB in;
	in_lq = colour_transform_to Image_type.LABQ in;
	params = [ 5, 2.5, 40, 20, 0.5, 1.5 ];
	out = colour_transform_to Image_type.LAB (sharpen params?0 params?1 params?2 params?3 params?4 params?5 in_lq);
}

ctype = ((Image_file) "$image_path").type;
cband = ((Image_file) "$image_path").bands;
coding = ((Image_file) "$image_path").coding;
main = (get_image @ stage_sRGB @ stage_sharp @ stage_saturate @ stage_RGB16 @ Image_file) "$image_path", ctype == 25
	   //= (get_image @ Image_file) "$image_path", ctype == 26 //problems sharpening 
	   = (get_image @ stage_sRGB @ Image_file) "$image_path", ctype == 26 //problems sharpening 
	   = (get_image @ Image_file) "$image_path", ctype == 1 
	   = (get_image @ stage_4band @ Image_file) "$image_path", cband == 4 && coding !=2
		 = (get_image @ stage_sRGB @ stage_sharp @ stage_saturate @ Image_file) "$image_path";

EOF

	if [ `$VIPSHOME/bin/header -f "Xsize" $temp` ]; then
		#echo "GOOD: $output_name"	
		mv $temp "$output_name";
	else
		echo "FAILED TO CREATE $bd $ba $output_name
$output";
	fi
#fi
